pilas.colisiones.Colisiones

Package pilas :: Module colisiones :: Class Colisiones |
[hide private]
[frames] | no frames]

# Class Colisiones

source code

Administra todas las colisiones entre actores.

Instance Methods | [hide private]
__init__(self) | source code
verificar_colisiones(self) | source code
_verificar_colisiones_en_tupla(self, tupla) Toma dos grupos de actores y analiza colisiones entre ellos. | source code
verificar_colisiones_fisicas(self, id_actor_a, id_actor_b) | source code
_verificar_colisiones_fisicas_en_tupla(self, tupla, id_actor_a, id_actor_b) Toma dos grupos de actores y analiza colisiones entre ellos. | source code
_es_objeto_fisico_con_actor_asociado(self, objeto) | source code
agregar(self, grupo_a, grupo_b, funcion_a_llamar) Agrega dos listas de actores para analizar colisiones. | source code
eliminar_colisiones_con_actor(self, actor) | source code
obtener_colisiones(self, actor, grupo_de_actores) Retorna una lista de los actores que colisionan con uno en particular. | source code